@@ -151,10 +151,11 @@ class GraphModel:
         # load from saved model
         if prev_model:
             self.load_weights(prev_model)
-        is_classification = 'entropy' in self.model.loss
+        is_classification = 'entropy' in str(self.model.loss)
         monitor = 'val_acc' if is_classification else 'val_mae'
         mode = 'max' if is_classification else 'min'
         dirname = kwargs.pop('dirname', 'callback')
+        has_sample_weights = sample_weights is not None
         if not os.path.isdir(dirname):
             os.makedirs(dirname)
         if callbacks is None:
@@ -171,13 +172,6 @@ class GraphModel:
             val_generator = self._create_generator(*val_inputs,
                                                    batch_size=batch_size)
             steps_per_val = int(np.ceil(len(validation_graphs) / batch_size))
-            if automatic_correction:
-                callbacks.extend([ReduceLRUponNan(filepath=filepath,
-                                                  monitor=monitor,
-                                                  mode=mode,
-                                                  factor=lr_scaling_factor,
-                                                  patience=patience,
-                                                  )])
             if save_checkpoint:
                 callbacks.extend([ModelCheckpointMAE(filepath=filepath,
                                                      monitor=monitor,
@@ -190,6 +184,15 @@ class GraphModel:
                 # avoid running validation twice in an epoch
                 val_generator = None  # type: ignore
                 steps_per_val = None  # type: ignore
+
+            if automatic_correction:
+                callbacks.extend([ReduceLRUponNan(filepath=filepath,
+                                                  monitor=monitor,
+                                                  mode=mode,
+                                                  factor=lr_scaling_factor,
+                                                  patience=patience,
+                                                  has_sample_weights=has_sample_weights
+                                                  )])
         else:
             val_generator = None  # type: ignore
             steps_per_val = None  # type: ignore
